package com.diagbot.process;

import com.diagbot.biz.push.entity.Lis;
import com.diagbot.dto.BillMsg;
import com.diagbot.dto.IndicationDTO;
import com.diagbot.dto.NodeNeoDTO;
import com.diagbot.dto.OtherTipNeoDTO;
import com.diagbot.dto.OtherTipTransfusionNeoDTO;
import com.diagbot.dto.WordCrfDTO;
import com.diagbot.enums.TypeEnum;
import com.diagbot.util.CoreUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @Description: 其他提示总入口
 * @author: zhoutg
 * @time: 2018/8/6 9:11
 */
@Component
public class OtherTipProcess {

    /**
     * 处理业务
     *
     * @param otherTipNeoDTOList
     * @param wordCrfDTO
     * @param res
     */
    public void processLis(List<OtherTipNeoDTO> otherTipNeoDTOList, WordCrfDTO wordCrfDTO, IndicationDTO res) {
        // 化验结果与诊断和开单药品进行匹配
        for (OtherTipNeoDTO otherTipNeoDTO : otherTipNeoDTOList) {
            List<NodeNeoDTO> factor = otherTipNeoDTO.getFactor();

            if (ListUtil.isNotEmpty(factor)) {
                for (NodeNeoDTO nodeNeoDTO : factor) {
                    Boolean flag = false;
                    if (TypeEnum.disease.getName().equals(nodeNeoDTO.getTermtype())) { // 诊断
                        flag = CoreUtil.compareNameWithNodeNeoDTO(nodeNeoDTO, wordCrfDTO.getDiag());
                    } else if (TypeEnum.drug.getName().equals(nodeNeoDTO.getTermtype())) { // 药品
                        flag = CoreUtil.compareNameWithNodeNeoDTO(nodeNeoDTO, wordCrfDTO.getDrug());
                    }
                    if (flag) {
                        String content = otherTipNeoDTO.getName() + otherTipNeoDTO.getDetailName();
                        if (StringUtil.isNotBlank(otherTipNeoDTO.getOtherValue())) {
                            content += otherTipNeoDTO.getOtherValue();
                        } else {
                            content += otherTipNeoDTO.getValue();
                        }
                        BillMsg billMsg = CoreUtil.getCommonOtherTipLisMsg(content, nodeNeoDTO.getName(), nodeNeoDTO.getTermtype());
                        res.getOtherList().add(billMsg);
                    }
                }
            }
        }
    }

    /**
     * 处理业务——输入
     *
     * @param otherTipTransfusionNeoDTOList
     * @param res
     */
    public void processTransfusion(List<OtherTipTransfusionNeoDTO> otherTipTransfusionNeoDTOList, IndicationDTO res) {
        for (OtherTipTransfusionNeoDTO bean : otherTipTransfusionNeoDTOList) {
            StringBuffer sb = new StringBuffer();
            if (ListUtil.isNotEmpty(bean.getDiag())) {
                sb.append("诊断");
                List<String> diag = bean.getDiag().stream().map(r -> r.getName()).collect(Collectors.toList());
                sb.append(StringUtils.join(diag));
            }
            if (ListUtil.isNotEmpty(bean.getOperation())) {
                List<String> operation = bean.getOperation().stream().map(r -> r.getName()).collect(Collectors.toList());
                if (sb.toString().length() > 0) {
                    sb.append("，");
                }
                sb.append(StringUtils.join(operation));
            }
            // if (ListUtil.isNotEmpty(bean.getPacsLabel().getPacsNewList())) {
            //     List<PacsNew> pacsNewList = bean.getPacsLabel().getPacsNewList();
            //     for (PacsNew pacsNew : pacsNewList) {
            //         if (sb.toString().length() > 0) {
            //             sb.append("，");
            //         }
            //         sb.append(pacsNew.getName() + StringUtils.join(pacsNew.getMatchRes()));
            //     }
            // }
            if (ListUtil.isNotEmpty(bean.getLisList())) {
                for (Lis lis : bean.getLisList()) {
                    if (sb.toString().length() > 0) {
                        sb.append("，");
                    }
                    sb.append(lis.getName() + lis.getDetailName() + lis.getOtherValue() + CoreUtil.getLisValue(lis));
                }
            }
        }
    }
}
